@@ -45,6 +45,7 @@ from ._utils import deepmerge
 from .defaults import CFGFILE_SEARCH_PATHS, make_config
 from .flask import FlaskHelper
 from .gunicorn import GunicornHelper
+from torxtools.argtools import is_not_dir
 
 
 def _read(cfgfile: str) -> t.Dict[str, t.Any]:
@@ -237,6 +238,7 @@ class ArgParse:
         parser.add_argument(
          "-c", "--cfgfile", metavar="CFGFILE",
            help=helpmsg_cfgfile,
+           type=is_not_dir,
         )
         parser.add_argument(
             "--ui", action="store_true", default=None,
